pub struct CreateDomain {
pub domain: String,
pub allow_conflicting_provider: Option<bool>,
pub feedback_enabled: Option<bool>,
pub inbound_enabled: Option<bool>,
pub subdomains_enabled: Option<bool>,
pub tracking_enabled: Option<bool>,
}Expand description
Request body for create_domain.
Fields
domain: StringThe domain name to add.
allow_conflicting_provider: Option<bool>Proceed even if the domain’s DNS is managed by another provider.
feedback_enabled: Option<bool>Enable bounce/complaint feedback.
inbound_enabled: Option<bool>Deliver inbound mail for this domain to agent inboxes.
subdomains_enabled: Option<bool>Allow subdomains of this domain to be used for inboxes.
tracking_enabled: Option<bool>Enable open/click tracking for this domain.