pub struct SendAttachment {
pub filename: Option<String>,
pub content_type: Option<String>,
pub content_disposition: Option<String>,
pub content_id: Option<String>,
pub content: Option<String>,
pub url: Option<String>,
}Expand description
An attachment to include on an outgoing message or draft. Supply the bytes
inline as base64 content, or a url for the API to fetch; set content_id
to reference the attachment inline from the HTML body.
Fields
filename: Option<String>File name.
content_type: Option<String>MIME content type.
content_disposition: Option<String>Content-Disposition (e.g. inline or attachment).
content_id: Option<String>Content-ID, to reference this attachment inline from the HTML body.
content: Option<String>The attachment bytes, base64-encoded.
url: Option<String>A URL for the API to fetch the attachment from, instead of content.